Vera&John | The fun casino

- Forgot password?

Help centre

## I forgot my password

- Have you forgotten your password? Since all our passwords are encrypted we cannot retrieve it for you.
  Please enter your email address and we will send you a link that will allow you to reset your password. This link will only be valid for 24 hours and can only be used once.
  If your email address is no longer valid you will need to contact our Customer Service team.

- Your email address
- Please pull the slider to the right to show that you are a human.
  You need at least Flash 10.0 support and Javascript enabled.

--:--

### Alert messages

Loading...

### Welcome to Vera&John

## Make your experience even better!

We want you to get the most out of your experience with us so we recommend that you upgrade your web browser to a newer version or to another web browser. This way you can enjoy all the games and graphics at Vera&John. Just click on an icon below to get to the download page for a free update from the official website!

###

Loading...